Index: code/branches/cpp11_v3/src/orxonox/interfaces/NotificationListener.cc
===================================================================
--- code/branches/cpp11_v3/src/orxonox/interfaces/NotificationListener.cc	(revision 11053)
+++ code/branches/cpp11_v3/src/orxonox/interfaces/NotificationListener.cc	(revision 11054)
@@ -108,9 +108,9 @@
     {
         // Iterate through all NotificationListeners and notify them by calling the method they overloaded.
-        for(ObjectList<NotificationListener>::iterator it = ObjectList<NotificationListener>::begin(); it != ObjectList<NotificationListener>::end(); ++it)
+        for(NotificationListener* listener : ObjectList<NotificationListener>())
         {
             // If the notification is a message.
             if(!isCommand)
-                it->registerNotification(message, sender, notificationMessageType::Value(messageType));
+                listener->registerNotification(message, sender, notificationMessageType::Value(messageType));
 
             // If the notification is a command.
@@ -119,5 +119,5 @@
                 notificationCommand::Value command = str2Command(message);
                 if(command != notificationCommand::none)
-                    it->executeCommand(command, sender);
+                    listener->executeCommand(command, sender);
             }
         }
Index: code/branches/cpp11_v3/src/orxonox/interfaces/PickupCarrier.cc
===================================================================
--- code/branches/cpp11_v3/src/orxonox/interfaces/PickupCarrier.cc	(revision 11053)
+++ code/branches/cpp11_v3/src/orxonox/interfaces/PickupCarrier.cc	(revision 11054)
@@ -101,7 +101,7 @@
         // Go recursively through all children to check whether they are a target.
         std::vector<PickupCarrier*>* children = this->getCarrierChildren();
-        for(std::vector<PickupCarrier*>::const_iterator it = children->begin(); it != children->end(); it++)
+        for(PickupCarrier* carrier : *children)
         {
-            if((*it)->isTarget(pickup))
+            if(carrier->isTarget(pickup))
             {
                 isTarget = true;
@@ -127,17 +127,17 @@
     {
         if(!this->isTarget(pickup))
-            return NULL;
+            return nullptr;
 
         if(pickup->isTarget(this)) // If the PickupCarrier itself is a target.
             return this;
 
-        PickupCarrier* target = NULL;
+        PickupCarrier* target = nullptr;
         // Go recursively through all children to check whether they are the target.
         std::vector<PickupCarrier*>* children = this->getCarrierChildren();
-        for(std::vector<PickupCarrier*>::iterator it = children->begin(); it != children->end(); it++)
+        for(PickupCarrier* child : *children)
         {
-            if(pickup->isTarget(*it))
+            if(pickup->isTarget(child))
             {
-                target = *it;
+                target = child;
                 break;
             }
Index: code/branches/cpp11_v3/src/orxonox/interfaces/PickupCarrier.h
===================================================================
--- code/branches/cpp11_v3/src/orxonox/interfaces/PickupCarrier.h	(revision 11053)
+++ code/branches/cpp11_v3/src/orxonox/interfaces/PickupCarrier.h	(revision 11054)
@@ -59,5 +59,5 @@
         But this structure has to be established first.
         - <b>getCarrierChildren()</b> To this end a PickupCarrier needs to implement getCarrierChildren() which returns a list of its direct PickupCarrier children. If you need an example, have a look at @ref orxonox::Pawn "Pawn" and @ref orxonox::Engine "Engine".
-        - <b>getCarrierParent()</b> This is the method in the other direction. It returns the parent of this PickupCarrier, or NULL if the PickupCarrier is a root node in this hierarchy.
+        - <b>getCarrierParent()</b> This is the method in the other direction. It returns the parent of this PickupCarrier, or nullptr if the PickupCarrier is a root node in this hierarchy.
 
     @author
@@ -77,5 +77,5 @@
             PickupCarrier(); //!< Constructor.
             virtual ~PickupCarrier(); //!< Destructor.
-            void preDestroy(void); //!< Is called before the PickupCarrier is effectively destroyed.
+            virtual void preDestroy(void) override; //!< Is called before the PickupCarrier is effectively destroyed.
 
             bool isTarget(const Pickupable* pickup) const; //!< Can be used to check whether the PickupCarrier or a child of his is a target ot the input Pickupable.
Index: code/branches/cpp11_v3/src/orxonox/interfaces/PickupListener.cc
===================================================================
--- code/branches/cpp11_v3/src/orxonox/interfaces/PickupListener.cc	(revision 11053)
+++ code/branches/cpp11_v3/src/orxonox/interfaces/PickupListener.cc	(revision 11054)
@@ -74,6 +74,6 @@
 
         // Iterate through all PickupListeners and notify them by calling the method they overloaded.
-        for(ObjectList<PickupListener>::iterator it = ObjectList<PickupListener>::begin(); it != ObjectList<PickupListener>::end(); ++it)
-            it->pickupChangedUsed(pickup, used);
+        for(PickupListener* listener : ObjectList<PickupListener>())
+            listener->pickupChangedUsed(pickup, used);
     }
 
@@ -92,6 +92,6 @@
 
         // Iterate through all PickupListeners and notify them by calling the method they overloaded.
-        for(ObjectList<PickupListener>::iterator it = ObjectList<PickupListener>::begin(); it != ObjectList<PickupListener>::end(); ++it)
-            it->pickupChangedPickedUp(pickup, pickedUp);
+        for(PickupListener* listener : ObjectList<PickupListener>())
+            listener->pickupChangedPickedUp(pickup, pickedUp);
     }
 
Index: code/branches/cpp11_v3/src/orxonox/interfaces/Pickupable.h
===================================================================
--- code/branches/cpp11_v3/src/orxonox/interfaces/Pickupable.h	(revision 11053)
+++ code/branches/cpp11_v3/src/orxonox/interfaces/Pickupable.h	(revision 11054)
@@ -144,5 +144,5 @@
 
         protected:
-            virtual void preDestroy(void); //!< A method that is called by Destroyable::destroy() before the object is actually destroyed.
+            virtual void preDestroy(void) override; //!< A method that is called by Destroyable::destroy() before the object is actually destroyed.
             virtual void destroyPickup(void); //!< Destroys a Pickupable.
             virtual void carrierDestroyed(void); //!< Is called by the PickupCarrier when it is being destroyed.
@@ -182,5 +182,5 @@
         // For implementing the Rewardable interface:
         public:
-            virtual bool reward(PlayerInfo* player); //!< Method to transcribe a Pickupable as a Rewardable to the player.
+            virtual bool reward(PlayerInfo* player) override; //!< Method to transcribe a Pickupable as a Rewardable to the player.
 
     };
Index: code/branches/cpp11_v3/src/orxonox/interfaces/RadarViewable.h
===================================================================
--- code/branches/cpp11_v3/src/orxonox/interfaces/RadarViewable.h	(revision 11053)
+++ code/branches/cpp11_v3/src/orxonox/interfaces/RadarViewable.h	(revision 11054)
@@ -66,5 +66,5 @@
                 if (name == "HIDDEN")
                 {
-                    this->bVisibility_ = 0;
+                    this->bVisibility_ = false;
                     this->settingsChanged();
                 }

Index: code/branches/cpp11_v3/src/orxonox/interfaces/Pickupable.cc
===================================================================
--- code/branches/cpp11_v3/src/orxonox/interfaces/Pickupable.cc	(revision 11053)
+++ code/branches/cpp11_v3/src/orxonox/interfaces/Pickupable.cc	(revision 11054)
@@ -56,5 +56,5 @@
         RegisterObject(Pickupable);
 
-        this->carrier_ = NULL;
+        this->carrier_ = nullptr;
 
         this->beingDestroyed_ = false;
@@ -143,5 +143,5 @@
     bool Pickupable::isTarget(const PickupCarrier* carrier) const
     {
-        if(carrier == NULL)
+        if(carrier == nullptr)
             return false;
 
@@ -160,7 +160,7 @@
     {
         // Iterate through all targets of this Pickupable.
-        for(std::list<Identifier*>::const_iterator it = this->targets_.begin(); it != this->targets_.end(); it++)
+        for(Identifier* target : this->targets_)
         {
-            if(identifier->isA(*it))
+            if(identifier->isA(target))
                 return true;
         }
@@ -210,5 +210,5 @@
     bool Pickupable::pickup(PickupCarrier* carrier)
     {
-        if(carrier == NULL || this->isPickedUp()) // If carrier is NULL or the Pickupable is already picked up.
+        if(carrier == nullptr || this->isPickedUp()) // If carrier is nullptr or the Pickupable is already picked up.
             return false;
 
@@ -237,5 +237,5 @@
             return false;
 
-        assert(this->getCarrier()); // The Carrier cannot be NULL at this point.
+        assert(this->getCarrier()); // The Carrier cannot be nullptr at this point.
         if(!this->getCarrier()->removePickup(this)) //TODO Shouldn't this be a little later?
             orxout(internal_warning, context::pickups) << "Pickupable (&" << this << ", " << this->getIdentifier()->getName() << ") is being dropped, but it was not present in the PickupCarriers list of pickups." << endl;
@@ -249,5 +249,5 @@
             created = this->createSpawner();
 
-        this->setCarrier(NULL);
+        this->setCarrier(nullptr);
 
         if(!created && createSpawner) // If a PickupSpawner should have been created but wasn't.
@@ -301,5 +301,5 @@
         orxout(verbose, context::pickups) << "Pickupable (&" << this << ") changed Carrier (& " << carrier << ")." << endl;
 
-        if(carrier != NULL && tell)
+        if(carrier != nullptr && tell)
         {
             if(!carrier->addPickup(this))